@@ -14,12 +14,26 @@ from hbshare.rm_associated.util.regressions import Regression
 class StyleAttributionOutputs:
     def __init__(self):
         self.attribution_df = None
+        self.attribution_summary = None
+        self.attr_df = None
         self.r_square_series = None
         self.exposure_series = None
         self.return_attr_series = None
         self.style_allo_bar = None
         self.style_allo_line = None
 
+    def to_dict(self):
+        return {
+            "attribution_df": self.attribution_df,
+            "attribution_summary": self.attribution_summary,
+            "attr_df": self.attr_df,
+            "r_square_series": self.r_square_series,
+            "exposure_series": self.exposure_series,
+            "return_attr_series": self.return_attr_series,
+            "style_all_bar": self.style_allo_bar,
+            "style_allo_line": self.style_allo_line
+        }
+
 
 class StyleAttribution:
     def __init__(self, fund_id, fund_type, start_date, end_date, factor_type, benchmark_id, nav_frequency):
@@ -277,26 +291,68 @@ class StyleAttribution:
 
         return attr_summary, r_square_series, exposure_series, return_attr_series, total_attr_df, total_return_df
 
-    def get_all(self):
+    def get_all(self, processed=True):
         output = StyleAttributionOutputs()
 
         attr_summary, r_square_series, exposure_series, return_attr_series, total_attr_df, total_return_df = \
             self._style_analysis()
 
-        output.attribution_df = attr_summary
-        output.r_square_series = r_square_series
-        output.exposure_series = exposure_series
-        output.return_attr_series = return_attr_series
-        output.style_allo_bar = total_attr_df
-        output.style_allo_line = total_return_df
+        if processed:
+            attr_summary['fund_id'] = self.fund_id
+            attr_summary['attr_type'] = self.factor_type
+            # 整合
+            r_square_series.index.name = 'date'
+            r_square_series = r_square_series.to_frame(name='value').reset_index()
+            r_square_series['style_factor'] = 'r_square'
+            r_square_series['value_type'] = 'r_square'
 
-        return output
+            exposure_series = exposure_series.stack().to_frame(name='value').reset_index()
+            exposure_series['value_type'] = 'exposure'
+            return_attr_series = return_attr_series.stack().to_frame(name='value').reset_index()
+            return_attr_series['value_type'] = 'return'
+
+            attr_df = pd.concat([exposure_series, return_attr_series, r_square_series])
+            attr_df['fund_id'] = self.fund_id
+            attr_df['attr_type'] = self.factor_type
+            attr_df = attr_df[['fund_id', 'date', 'attr_type', 'value_type', 'style_factor', 'value']]
+
+            total_attr_df.index.name = 'date'
+            total_attr_df.reset_index(inplace=True)
+            total_attr_df['fund_id'] = self.fund_id
+            total_attr_df['attr_type'] = self.factor_type
+            total_attr_df = total_attr_df[['fund_id', 'date', 'attr_type', 'benchmark', 'allocation', 'selection']]
+
+            total_return_df = total_return_df.reset_index()
+            total_return_df['fund_id'] = self.fund_id
+            total_return_df['attr_type'] = self.factor_type
+            total_return_df = total_return_df[
+                ['fund_id', 'tradeDate', 'attr_type', 'portfolio', 'benchmark', 'dynamic_style_bm']]
+
+            output.attribution_summary = attr_summary
+            output.attr_df = attr_df
+            output.style_allo_bar = total_attr_df
+            output.style_allo_line = total_return_df
+        else:
+            output.attribution_df = attr_summary
+            output.r_square_series = r_square_series
+            output.exposure_series = exposure_series
+            output.return_attr_series = return_attr_series
+            output.style_allo_bar = total_attr_df
+            output.style_allo_line = total_return_df
+
+        # import pickle
+        # with open('D:\\kevin\\nav_attribution_sample_data.pickle', 'wb') as f:
+        #     pickle.dump(output.to_dict(), f)
+
+        return output.to_dict()
 
 
 if __name__ == '__main__':
     # 公募样例：110011
     # res = StyleAttribution(fund_id='110011', fund_type='mutual', start_date='20181120', end_date='20210120',
-    #                        factor_type='style_allo', benchmark_id='000300', nav_frequency='day').get_all(isPlot=True)
+    #                        factor_type='style_allo', benchmark_id='000300', nav_frequency='day').get_all(processed=False)
     # 私募样例
-    res = StyleAttribution(fund_id='110011', fund_type='mutual', start_date='20190220', end_date='20210120',
-                           factor_type='sector', benchmark_id='000300', nav_frequency='day').get_all()
+    # res = StyleAttribution(fund_id='110011', fund_type='mutual', start_date='20190220', end_date='20210120',
+    #                        factor_type='sector', benchmark_id='000300', nav_frequency='day').get_all()
+    res = StyleAttribution(fund_id='P11697', fund_type='private', start_date='20151220', end_date='20210621',
+                           factor_type='style_allo', benchmark_id='000985', nav_frequency='week').get_all()
